@@ -42,6 +42,9 @@ def test_basic_instantiation():
         "redis": {
             "url": "redis://localhost:6379/0"
         },
+        "security": {
+            "csp": {},
+        },
     })
 
 
@@ -100,7 +103,7 @@ def test_wsgi_app(app, monkeypatch):
     monkeypatch.setattr(importlib, "import_module", import_module)
 
     environ = create_environ()
-    start_response = pretend.stub()
+    start_response = pretend.stub(__name__=str("start_response"))
 
     app.urls = urls
     app.wsgi_app(environ, start_response)
@@ -135,7 +138,7 @@ def test_wsgi_app_exception(app, monkeypatch):
     monkeypatch.setattr(importlib, "import_module", import_module)
 
     environ = create_environ()
-    start_response = pretend.stub()
+    start_response = pretend.stub(__name__=str("start_response"))
 
     app.urls = urls
 
